HeyhipAmapPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • HeyhipAmapPlatform
Implementers

Constructors

HeyhipAmapPlatform()
Constructs a HeyhipAmapPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCurrentLocation() Future<HeyhipLocation?>
getPlatformVersion() Future<String?>
hasLocationPermission() Future<bool>
initKey({required String apiKey}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestLocationPermission() Future<void>
toString() String
A string representation of this object.
inherited
updatePrivacy({required bool hasContains, required bool hasShow, required bool hasAgree}) Future<void>
隐私合规

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance HeyhipAmapPlatform
The default instance of HeyhipAmapPlatform to use.
getter/setter pair